@@ -23,7 +23,7 @@
 
     */
 
-#include "core.h"
+#include "common.h"
 #include <stdio.h>
 
 using namespace Arts;
